##############################################################################
#
# Copyright (c) 2011 Nexedi SARL and Contributors. All Rights Reserved.
#                     Kazuhiko <kazuhiko@nexedi.com>
#                     Rafael Monnerat <rafael@nexedi.com>
#
# WARNING: This program as such is intended to be used by professional
# programmers who take the whole responsability of assessing all potential
# consequences resulting from its eventual inadequacies and bugs
# End users who are looking for a ready-to-use solution with commercial
# garantees and support are strongly adviced to contract a Free Software
# Service Company
#
# This program is Free Software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
##############################################################################

import unittest, random

from Products.ERP5Type.tests.ERP5TypeFunctionalTestCase import \
        ERP5TypeFunctionalTestCase

class TestZeleniumStandaloneSlapOSTutorial(ERP5TypeFunctionalTestCase):
  foreground = 0
  run_only = "slapos_tutorial_zuite"

  def clearCache(self):
    self.portal.portal_caches.clearAllCache()
    self.portal.portal_workflow.refreshWorklistCache()

  def afterSetUp(self):
    url_list = []
    for x in self.portal.test_page_module.objectValues():
      if "slapos-Tutorial" in x.getId():
        url_list.append("test_page_module/"+x.getId())
    self.remote_code_url_list = url_list
    ERP5TypeFunctionalTestCase.afterSetUp(self)

    # Execute the business configuration if not installed
    business_configuration = self.getBusinessConfiguration()
    if (business_configuration.getSimulationState() != 'installed'):
      self.portal.portal_caches.erp5_site_global_id = '%s' % random.random()
      self.portal.portal_caches._p_changed = 1
      self.commit()
      self.portal.portal_caches.updateCache()

      self.bootstrapSite()
      self.commit()

  def bootstrapSite(self):
    self.logMessage('SlapOS Master bootstrapSite')

    self.clearCache()
    self.tic()
    self.setUpConfiguratorOnce()
    self.tic()

  def setUpConfiguratorOnce(self):
    self.commit()
    self.portal.portal_templates.updateRepositoryBusinessTemplateList(
       repository_list=self.portal.portal_templates.getRepositoryList())
    self.commit()
    self.launchConfigurator()

  def launchConfigurator(self):
    self.logMessage('SlapOS Master launchConfigurator')
    self.login()
    # Create new Configuration
    business_configuration  = self.getBusinessConfiguration()
    self.portal.portal_configurator._next(business_configuration, {})
    '''
    response_dict = {}
    previous_title = None
    while response_dict.get("command", "next") != "install":
      title = response_dict.get("next", "")
      if title == previous_title:
        # transition = business_configuration.getNextTransition()
        # form = getattr(business_configuration, transition.getTransitionFormId())
        # raise NotImplementedError(form(), response_dict)
        break
      previous_title = title
      response_dict = self.portal.portal_configurator._next(
                            business_configuration, {})
                            '''

    self.tic()
    self.portal.portal_configurator.startInstallation(
                 business_configuration,REQUEST=self.portal.REQUEST)

  def getBusinessConfiguration(self):
    return self.portal.business_configuration_module[\
                          "slapos_master_configuration_workflow"]

  def getBusinessTemplateList(self):
    """
      Return the list of business templates.
    """
    return ('erp5_full_text_mroonga_catalog',
            'erp5_configurator',
           )

def test_suite():
  suite = unittest.TestSuite()
  suite.addTest(unittest.makeSuite(TestZeleniumStandaloneSlapOSTutorial))
  return suite